@@ -5,6 +5,7 @@
 
 import logging
 import textwrap
+from typing import List
 from unittest.mock import patch
 
 import click
@@ -12,35 +13,68 @@ from click.testing import CliRunner
 import pkg_resources
 import pytest
 
-help_msg = """Usage: swh [OPTIONS] COMMAND [ARGS]...
+help_msg_snippets = (
+    (
+        "Usage",
+        (
+            "swh [OPTIONS] COMMAND [ARGS]...",
+            "Command line interface for Software Heritage.",
+        ),
+    ),
+    ("Options", ("-l, --log-level", "--log-config", "--sentry-dsn", "-h, --help",)),
+)
 
-  Command line interface for Software Heritage.
 
-Options:
-  -l, --log-level [NOTSET|DEBUG|INFO|WARNING|ERROR|CRITICAL]
-                                  Log level (defaults to INFO).
-  --log-config FILENAME           Python yaml logging configuration file.
-  --sentry-dsn TEXT               DSN of the Sentry instance to report to
-  -h, --help                      Show this message and exit.
+def get_section(cli_output: str, section: str) -> List[str]:
+    """Get the given `section` of the `cli_output`"""
+    result = []
+    in_section = False
+    for line in cli_output.splitlines():
+        if not line:
+            continue
 
-Notes:
-  If both options are present, --log-level will override the root logger
-  configuration set in --log-config.
+        if in_section:
+            if not line.startswith(" "):
+                break
+        else:
+            if line.startswith(section):
+                in_section = True
 
-  The --log-config YAML must conform to the logging.config.dictConfig schema
-  documented at https://docs.python.org/3/library/logging.config.html.
-"""
+        if in_section:
+            result.append(line)
+
+    return result
+
+
+def assert_section_contains(cli_output: str, section: str, snippet: str) -> bool:
+    """Check that a given `section` of the `cli_output` contains the given `snippet`"""
+    section_lines = get_section(cli_output, section)
+    assert section_lines, "Section %s not found in output %r" % (section, cli_output)
+
+    for line in section_lines:
+        if snippet in line:
+            return True
+    else:
+        assert False, "%r not found in section %r of output %r" % (
+            snippet,
+            section,
+            cli_output,
+        )
 
 
 def test_swh_help(swhmain):
     runner = CliRunner()
     result = runner.invoke(swhmain, ["-h"])
     assert result.exit_code == 0
-    assert result.output.startswith(help_msg)
+    for section, snippets in help_msg_snippets:
+        for snippet in snippets:
+            assert_section_contains(result.output, section, snippet)
 
     result = runner.invoke(swhmain, ["--help"])
     assert result.exit_code == 0
-    assert result.output.startswith(help_msg)
+    for section, snippets in help_msg_snippets:
+        for snippet in snippets:
+            assert_section_contains(result.output, section, snippet)
 
 
 def test_command(swhmain):
@@ -67,7 +101,6 @@ def test_loglevel_default(caplog, swhmain):
     runner = CliRunner()
     result = runner.invoke(swhmain, ["test"])
     assert result.exit_code == 0
-    print(result.output)
     assert result.output.strip() == """Hello SWH!"""
 
 
@@ -209,7 +242,7 @@ def log_config_path(tmp_path):
     yield str(tmp_path / "log_config.yml")
 
 
-def test_log_config(caplog, log_config_path, swhmain):
+def test_log_config(log_config_path, swhmain):
     @swhmain.command(name="test")
     @click.pass_context
     def swhtest(ctx):
@@ -231,7 +264,7 @@ def test_log_config(caplog, log_config_path, swhmain):
     )
 
 
-def test_log_config_log_level_interaction(caplog, log_config_path, swhmain):
+def test_log_config_log_level_interaction(log_config_path, swhmain):
     @swhmain.command(name="test")
     @click.pass_context
     def swhtest(ctx):
@@ -254,6 +287,36 @@ def test_log_config_log_level_interaction(caplog, log_config_path, swhmain):
     )
 
 
+def test_multiple_log_level_behavior(swhmain):
+    @swhmain.command(name="test")
+    @click.pass_context
+    def swhtest(ctx):
+        assert logging.getLevelName(logging.root.level) == "DEBUG"
+        assert logging.getLevelName(logging.getLogger("dontshowdebug").level) == "INFO"
+        return 0
+
+    runner = CliRunner()
+    result = runner.invoke(
+        swhmain, ["--log-level", "DEBUG", "--log-level", "dontshowdebug:INFO", "test",]
+    )
+
+    assert result.exit_code == 0, result.output
+
+
+def test_invalid_log_level(swhmain):
+    runner = CliRunner()
+    result = runner.invoke(swhmain, ["--log-level", "broken:broken:DEBUG"])
+
+    assert result.exit_code != 0
+    assert "Invalid log level specification" in result.output
+
+    runner = CliRunner()
+    result = runner.invoke(swhmain, ["--log-level", "UNKNOWN"])
+
+    assert result.exit_code != 0
+    assert "Log level UNKNOWN unknown" in result.output
+
+
 def test_aliased_command(swhmain):
     @swhmain.command(name="canonical-test")
     @click.pass_context
